@@ -78,39 +78,44 @@ stat_summary_address <- function(mapping = NULL, data = NULL, ...,
 
 StatSummaryAddress <- ggplot2::ggproto("StatSummaryAddress", ggplot2::Stat,
 
+  default_aes = ggplot2::aes(
+   ip = NULL,
+   z = NULL,
+   fill = ggplot2::after_stat(value)
+  ),
+
   # The `ip` aesthetic is required, but putting it in required_aes causes a very
   # slow check for missing values. It's much faster to simply check `x` and `y`
   # for missing values. These are always NA when `ip` is NA.
   required_aes = c("x", "y"),
 
-  default_aes = ggplot2::aes(
-    ip = NULL,
-    z = NULL,
-    fill = ggplot2::after_stat(value)
-  ),
+  dropped_aes = c("ip", "z"),
 
   extra_params = c("na.rm", "fun", "fun.args"),
 
   compute_layer = function(self, data, params, layout) {
     if (!is_CoordIp(layout$coord)) {
-      stop_missing_coord()
+      cli::cli_abort("{.pkg ggip} plots require {.fn coord_ip}.")
     }
 
     # validate ip aesthetic
     if (is.null(data$ip)) {
-      stop_missing_aes("stat_summary_address", "ip")
+      cli::cli_abort("{.fn {snake_class(self)}} requires an {.field ip} aesthetic.")
     } else if (is_ip_address_coords(data$ip)) {
       data$x <- data$ip$x
       data$y <- data$ip$y
       data$ip <- data$ip$ip
     } else if (is_ip_address(data$ip)) {
-      abort("The `ip` aesthetic of `stat_summary_address()` must map to a `data` variable.")
+      cli::cli_abort("The {.field ip} aesthetic of {.fn {snake_class(self)}} must map to a {.arg data} variable.")
     } else {
-      stop_bad_aes_type("stat_summary_address", "ip", "ip_address")
+      cli::cli_abort(c(
+        "The {.field ip} aesthetic of {.fn {snake_class(self)}} must be {.type {ip_address()}}.",
+        "x" = "You supplied {.type {data$ip}}."
+      ))
     }
 
     if (!is.null(params$fun) && !("z" %in% colnames(data))) {
-      abort("`stat_summary_address()` must have `z` aesthetic when using `fun` argument.")
+      cli::cli_abort("{.fn {snake_class(self)}} requires a {.field z} aesthetic when using the {.arg fun} argument.")
     }
 
     # add coord to the params, so it reaches compute_group()
